OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "نمیتوانید داخل دایرکتوری \"config\" تغییراتی ایجاد کنید",
    "This can usually be fixed by giving the web server write access to the config directory." : "This can usually be fixed by giving the web server write access to the config directory.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it.",
    "See %s" : "مشاهده %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory.",
    "Sample configuration detected" : "فایل پیکربندی نمونه پیدا شد",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "تشخیص داده شده است که پیکربندی نمونه کپی شده است. این می تواند نصب شما را خراب کند و پشتیبانی نمی شود. لطفاً قبل از انجام تغییرات در config.php ، اسناد را بخوانید",
    "The page could not be found on the server." : "The page could not be found on the server.",
    "%s email verification" : "%s email verification",
    "Email verification" : "Email verification",
    "Click the following button to confirm your email." : "Click the following button to confirm your email.",
    "Click the following link to confirm your email." : "Click the following link to confirm your email.",
    "Confirm your email" : "Confirm your email",
    "Other activities" : "سایر فعالیت ها",
    "%1$s and %2$s" : "%1$sو%2$s",
    "%1$s, %2$s and %3$s" : "%1$s،%2$sو%3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s،%2$s،%3$sو%4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s،%2$s،%3$s،%4$sو%5$s",
    "Enterprise bundle" : "بستهٔ سازمانی",
    "Groupware bundle" : "بستهٔ کار گروهی",
    "Hub bundle" : "بستهٔ هسته‌ای",
    "Social sharing bundle" : "بستهٔ هم‌رسانی اجتماعی",
    "PHP %s or higher is required." : "PHP نسخه‌ی %s یا بالاتر نیاز است.",
    "PHP with a version lower than %s is required." : "نیاز به نگارش پایین‌تر از %s پی‌اچ‌پی.",
    "%sbit or higher PHP required." : "نیاز به پی‌اچ‌پی %sبیتی یا بالاتر.",
    "The following architectures are supported: %s" : "معماری‌های زیر پشتیبانی می‌شوند: %s",
    "The following databases are supported: %s" : "پایگاه داده‌های زیر پشتیبانی می‌شوند: %s",
    "The command line tool %s could not be found" : "ابزار کامندلاین %s پیدا نشد",
    "The library %s is not available." : "کتابخانه‌ی %s  در دسترس نیست.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "کتاب‌خانهٔ %1$s با نگارشی بالاتر از %2$s مورد نیاز است - نگارش موجود %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "کتاب‌خانهٔ %1$s با نگارشی پایین‌تر از %2$s مورد نیاز است - نگارش موجود %3$s.",
    "The following platforms are supported: %s" : "بن‌سازه‌های زیر پشتیبانی می‌شوند: %s",
    "Server version %s or higher is required." : "نیاز به کارساز با نگارش %s یا بالاتر.",
    "Server version %s or lower is required." : "نیاز به کارساز با نگارش %s یا پایین‌تر.",
    "Wiping of device %s has started" : "پاک کردن دستگاه%s شروع شده است",
    "Wiping of device »%s« has started" : "پاک کردن دستگاه%s شروع شده است",
    "»%s« started remote wipe" : "%sپاک کردن از راه دور",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "دستگاه یا برنامه%s فرآیند پاک کردن از راه دور را آغاز کرده است. پس از اتمام مراحل ، ایمیل دیگری دریافت خواهید کرد",
    "Wiping of device %s has finished" : "پاک کردن دستگاه %sبه پایان رسیده است",
    "Wiping of device »%s« has finished" : "پاک کردن دستگاه %sبه پایان رسیده است",
    "»%s« finished remote wipe" : "%sپاک کردن از راه دور",
    "Device or application »%s« has finished the remote wipe process." : "دستگاه یا برنامه %sفرآیند پاک کردن از راه دور را به پایان رسانده است.",
    "Remote wipe started" : "پاک کردن از راه دور شروع شد",
    "A remote wipe was started on device %s" : "پاک کردن از راه دور روی دستگاه شروع شد%s",
    "Remote wipe finished" : "پاک کردن از راه دور به پایان رسید",
    "The remote wipe on %s has finished" : "پاک کردن از راه دور روی%s کار تمام شد",
    "Authentication" : "احراز هویت",
    "Unknown filetype" : "نوع فایل ناشناخته",
    "Invalid image" : "عکس نامعتبر",
    "Avatar image is not square" : "تصویر آواتار مربع نیست",
    "Files" : "پوشه‌ها",
    "View profile" : "مشاهدهٔ نمایه",
    "Local time: %s" : "Local time: %s",
    "today" : "امروز",
    "tomorrow" : "فردا",
    "yesterday" : "دیروز",
    "_in %n day_::_in %n days_" : ["در ۱ روز","در %n روز"],
    "_%n day ago_::_%n days ago_" : ["%n روز پیش","%n روز پیش"],
    "next month" : "ماه آینده",
    "last month" : "ماه قبل",
    "_in %n month_::_in %n months_" : ["در ۱ ماه","در %n ماه"],
    "_%n month ago_::_%n months ago_" : ["%n ماه قبل","%n ماه قبل"],
    "next year" : "سال آینده",
    "last year" : "سال قبل",
    "_in %n year_::_in %n years_" : ["در ۱ سال","در %nسال"],
    "_%n year ago_::_%n years ago_" : ["%n سال پیش","%n سال پیش"],
    "_in %n hour_::_in %n hours_" : ["در ۱ ساعت","در %n ساعت"],
    "_%n hour ago_::_%n hours ago_" : ["%n ساعت قبل","%n ساعت قبل"],
    "_in %n minute_::_in %n minutes_" : ["در ۱ دقیقه","در %n دقیقه"],
    "_%n minute ago_::_%n minutes ago_" : ["%n دقیقه قبل","%n دقیقه قبل"],
    "in a few seconds" : "در چند ثانیه",
    "seconds ago" : "ثانیه‌ها پیش",
    "Empty file" : "پروندهٔ خالی",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "ماژول با شناسه:%s وجود ندارد. لطفاً آن را در تنظیمات برنامه خود فعال کنید یا با سرپرست خود تماس بگیرید",
    "Dot files are not allowed" : "پرونده‌های نقطه‌دار مجاز نیستند",
    "File already exists" : "پرونده از پیش موجود است",
    "Invalid path" : "مسیر نامعتبر",
    "Failed to create file from template" : "شکست در ایجاد پرونده از قالب",
    "Templates" : "قالب‌ها",
    "Filename contains at least one invalid character" : "نام فایل حداقل دارای یک کاراکتر نامعتبر است",
    "Empty filename is not allowed" : "نام فایل نمی‌تواند خالی باشد",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "کارهٔ «%s» به دلیل ناتوانی در خواندن پروندهٔ appinfo نمی‌تواند نصب شود.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "کارهٔ «%s» به دلیل سازگار نبودن با این نگارش از کارساز نمی‌تواند نصب شود.",
    "__language_name__" : "فارسى",
    "This is an automatically sent email, please do not reply." : "این یک رایانامهٔ خودکار است. لطفاً پاسخ ندهید.",
    "Help & privacy" : "راهنما و حریم شخصی",
    "Appearance and accessibility" : "ظاهر و دسترسی‌پذیری",
    "Apps" : "  برنامه ها",
    "Personal settings" : "تنظیمات شخصی",
    "Administration settings" : "تنظمیات مدیریتی",
    "Settings" : "تنظیمات",
    "Log out" : "خروج",
    "Accounts" : "حساب‌ها",
    "Email" : "رایانامه",
    "Mail %s" : "نامه به %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "View %s on the fediverse",
    "Phone" : "تلفن",
    "Call %s" : "تماس با %s",
    "Twitter" : "توییتر",
    "View %s on Twitter" : "دیدن %s روی توییتر",
    "Website" : "پایگاه وب",
    "Visit %s" : "سر زدن به %s",
    "Address" : "نشانی",
    "Profile picture" : "تصویر نمایه",
    "About" : "درباره",
    "Display name" : "Display name",
    "Headline" : "عنوان",
    "Organisation" : "سازمان",
    "Role" : "نقش",
    "Additional settings" : "تنظیمات اضافی",
    "Enter the database name for %s" : "ورود نام پایگاه داده برای %s",
    "You cannot use dots in the database name %s" : "نمی‌توانید در در نام پایگاه دادهٔ %s از نقطه استفاده کنید",
    "You need to enter details of an existing account." : "لازم است جزییات یک حساب موحود را وارد کنید.",
    "Oracle connection could not be established" : "ارتباط اراکل نمیتواند برقرار باشد.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "مک‌اواس ۱۰ پشتیبانی نشده و %s روی این بن‌سازه درست کار نخواهد کرد. با مسئولیت خودتان استفاده کنید!",
    "For the best results, please consider using a GNU/Linux server instead." : "برای بهترین نتیجه، استفاده از یک کارساز گنو/لینوکسی را در نظر داشته باشید.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "به نظر می رسد%s که این نمونه در یک محیط PHP 32 بیتی در حال اجرا است و open_baseir در php.ini پیکربندی شده است. این مسئله به پرونده هایی با بیش از 4 گیگ منجر می شود و بسیار دلسرد می شود",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "لطفاً تنظیمات open_baseir را درون php.ini خود حذف کنید یا به PHP 64 بیتی تغییر دهید.",
    "Set an admin password." : "یک رمزعبور برای مدیر تنظیم نمایید.",
    "Cannot create or write into the data directory %s" : "Cannot create or write into the data directory %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "به اشتراک گذاشتن باطن باید رابط OCP \\ Share_Backend %sرا پیاده سازی کند",
    "Sharing backend %s not found" : "به اشتراک گذاشتن باطن%s یافت نشد",
    "Sharing backend for %s not found" : "به اشتراک گذاشتن باطن برای%s یافت نشد",
    "%1$s via %2$s" : "%1$s از طریق %2$s",
    "Unknown share type" : "نوع اشتراک ناشناخته",
    "You are not allowed to share %s" : "شما مجاز به اشتراک گذاری نیستید%s",
    "Cannot increase permissions of %s" : "Cannot increase permissions of %s",
    "Files cannot be shared with delete permissions" : "Files cannot be shared with delete permissions",
    "Files cannot be shared with create permissions" : "Files cannot be shared with create permissions",
    "Expiration date is in the past" : "تاریخ انقضا در گذشته است",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Cannot set expiration date more than %n day in the future","Cannot set expiration date more than %n days in the future"],
    "Sharing is only allowed with group members" : "Sharing is only allowed with group members",
    "The requested share does not exist anymore" : "سهم درخواست شده دیگر وجود ندارد",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "The user was not created because the user limit has been reached. Check your notifications to learn more.",
    "Could not find category \"%s\"" : "دسته بندی %s یافت نشد",
    "Sunday" : "یک‌شنبه",
    "Monday" : "دوشنبه",
    "Tuesday" : "سه‌شنبه",
    "Wednesday" : "چهارشنبه",
    "Thursday" : "پنج‌شنبه",
    "Friday" : "آدینه",
    "Saturday" : "شنبه",
    "Sun." : "یک.",
    "Mon." : "دو.",
    "Tue." : "سه.",
    "Wed." : "چهار.",
    "Thu." : "پنج.",
    "Fri." : "آد.",
    "Sat." : "شن.",
    "Su" : "ی",
    "Mo" : "د",
    "Tu" : "س",
    "We" : "چ",
    "Th" : "پ",
    "Fr" : "آ",
    "Sa" : "ش",
    "January" : "ژانویه",
    "February" : "فوریه",
    "March" : "مارس",
    "April" : "آوریل",
    "May" : "مه",
    "June" : "ژوئن",
    "July" : "جولای",
    "August" : "اوت",
    "September" : "سپتامبر",
    "October" : "اکتبر",
    "November" : "نوامبر",
    "December" : "دسامبر",
    "Jan." : "ژان.",
    "Feb." : "فو.",
    "Mar." : "مار.",
    "Apr." : "آو.",
    "May." : "مه.",
    "Jun." : "ژو.",
    "Jul." : "جول.",
    "Aug." : "اوت.",
    "Sep." : "سپ.",
    "Oct." : "اکت.",
    "Nov." : "نو.",
    "Dec." : "دس.",
    "A valid password must be provided" : "رمز عبور صحیح باید وارد شود",
    "Login canceled by app" : "ورود به دست کاره لغو شد",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "کارهٔ «%1$s» نمی‌تواند نصب شود؛ چرا که وابستگی زیر تأمین نشده: %2$s",
    "a safe home for all your data" : "خانه‌ای امن برای تمامی داده‌هایتان",
    "Application is not enabled" : "برنامه فعال نشده است",
    "Authentication error" : "خطا در اعتبار سنجی",
    "Token expired. Please reload page." : "Token منقضی شده است. لطفا دوباره صفحه را بارگذاری نمایید.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "هیچ درایور پایگاه داده (sqlite ، mysql یا postgresql) نصب نشده است.",
    "Cannot write into \"config\" directory." : "Cannot write into \"config\" directory.",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "This can usually be fixed by giving the web server write access to the config directory. See %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "یا اگر ترجیح می دهید پرونده config.php را فقط بخوانید ، گزینه \"config_is_read_only\" را در آن تنظیم کنید. دیدن%s",
    "Cannot write into \"apps\" directory." : "Cannot write into \"apps\" directory.",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file.",
    "Cannot create \"data\" directory." : "Cannot create \"data\" directory.",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "This can usually be fixed by giving the web server write access to the root directory. See %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Permissions can usually be fixed by giving the web server write access to the root directory. See %s.",
    "Your data directory is not writable." : "Your data directory is not writable.",
    "Setting locale to %s failed." : "Setting locale to %s failed.",
    "Please install one of these locales on your system and restart your web server." : "Please install one of these locales on your system and restart your web server.",
    "PHP module %s not installed." : "ماژول PHP %s نصب نشده است.",
    "Please ask your server administrator to install the module." : "لطفا از مدیر سیستم بخواهید تا ماژول را نصب کند.",
    "PHP setting \"%s\" is not set to \"%s\"." : "تنظیمات PHP%s تنظیم نشده است%s",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "تنظیم این تنظیمات در php.ini باعث می شود Nextcloud دوباره اجرا شود",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ظاهراً برای خنثی کردن بلوک های اسناد درون خطی تنظیم شده است. این کار چندین برنامه اصلی را غیرقابل دسترسی خواهد کرد.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "این احتمالاً توسط حافظه پنهان / کش مانند Zend OPcache یا eAccelerator ایجاد شده است.",
    "PHP modules have been installed, but they are still listed as missing?" : "ماژول های پی اچ پی نصب شده اند ، اما هنوز هم به عنوان مفقود شده ذکر شده اند؟",
    "Please ask your server administrator to restart the web server." : "لطفاً از سرور سرور خود بخواهید که وب سرور را مجدداً راه اندازی کند.",
    "The required %s config variable is not configured in the config.php file." : "The required %s config variable is not configured in the config.php file.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Please ask your server administrator to check the Nextcloud configuration.",
    "Your data directory must be an absolute path." : "Your data directory must be an absolute path.",
    "Check the value of \"datadirectory\" in your configuration." : "Check the value of \"datadirectory\" in your configuration.",
    "Your data directory is invalid." : "Your data directory is invalid.",
    "Action \"%s\" not supported or implemented." : "عملی%s پشتیبانی یا اجرا نشده است.",
    "Authentication failed, wrong token or provider ID given" : "تأیید اعتبار انجام نشد ، نشانه اشتباه یا شناسه ارائه دهنده داده شد",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "پارامترهای موجود برای تکمیل درخواست. پارامترهای موجود نیست%s",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "شناسه%1$s قبلاً توسط ارائه دهنده فدراسیون ابر استفاده شده است%2$s",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "ارائه دهنده فدراسیون Cloud با شناسه:%s وجود ندارد.",
    "Could not obtain lock type %d on \"%s\"." : "نمی توان نوع%d قفل را به دست آورد%s",
    "Storage unauthorized. %s" : "ذخیره سازی غیر مجاز.%s",
    "Storage incomplete configuration. %s" : "پیکربندی ناقص ذخیره سازی.%s<br>",
    "Storage connection error. %s" : "خطای اتصال ذخیره سازی%s",
    "Storage is temporarily not available" : "ذخیره سازی به طور موقت در دسترس نیست",
    "Storage connection timeout. %s" : "مدت زمان اتصال ذخیره سازی%s",
    "Confirmation" : "Confirmation",
    "Prompt" : "Prompt",
    "Chat" : "Chat",
    "Generates a possible headline for a text." : "Generates a possible headline for a text.",
    "Text" : "متن",
    "Summarize" : "Summarize",
    "Summary" : "چکیده",
    "Extract topics" : "Extract topics",
    "Translate" : "ترجمه",
    "Target language" : "Target language",
    "Result" : "شروع به اسکنیک",
    "Free prompt" : "Free prompt",
    "Runs an arbitrary prompt through the language model." : "Runs an arbitrary prompt through the language model.",
    "Generate headline" : "Generate headline",
    "Summarizes text by reducing its length without losing key information." : "Summarizes text by reducing its length without losing key information.",
    "Extracts topics from a text and outputs them separated by commas." : "Extracts topics from a text and outputs them separated by commas.",
    "Education Edition" : "نگارش آموزشی",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Logged in user must be an admin, a sub admin or gotten special right to access this setting",
    "Logged in user must be an admin or sub admin" : "ورود به سیستم کاربر باید یک مدیر یا مدیر فرعی باشد",
    "Logged in user must be an admin" : "ورود به سیستم کاربر باید مدیر سایت باشد",
    "File name is a reserved word" : "این نام فایل جزو کلمات رزرو می‌باشد",
    "File name contains at least one invalid character" : "نام فایل دارای حداقل یک کاراکتر نامعتبر است",
    "File name is too long" : "نام فایل خیلی بزرگ است",
    "Help" : "راهنما",
    "Users" : "کاربران",
    "Unknown user" : "کاربر نامعلوم",
    "Enter the database username and name for %s" : "ورود نام و نام کاربری پایگاه داده برای %s",
    "Enter the database username for %s" : "ورود نام کاربری پایگاه داده برای %s",
    "MySQL username and/or password not valid" : "نام کاربری یا گذرواژهٔ مای‌سکول معتبر نیست",
    "Oracle username and/or password not valid" : "نام کاربری و / یا رمزعبور اراکل معتبر نیست.",
    "PostgreSQL username and/or password not valid" : "PostgreSQL نام کاربری و / یا رمزعبور معتبر نیست.",
    "Set an admin username." : "یک نام کاربری برای مدیر تنظیم نمایید.",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s به اشتراک گذاشته شده »%2$s« با شماست و می خواهد اضافه کند:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s به اشتراک گذاشته شده »%2$s« با شماست و می خواهد اضافه کند:",
    "»%s« added a note to a file shared with you" : "»%s« یادداشتی را به پرونده ای که با شما به اشتراک گذاشته شده است اضافه کرد",
    "Open »%s«" : "باز کن »%s«",
    "Sharing %s failed, because this item is already shared with user %s" : "Sharing %s failed, because this item is already shared with user %s",
    "%1$s shared »%2$s« with you" : "%1$s به اشتراک گذاشته » %2$s« با شما",
    "%1$s shared »%2$s« with you." : "%1$s به اشتراک گذاشته » %2$s« با شما",
    "Click the button below to open it." : "برای باز کردن آن روی دکمه زیر کلیک کنید.",
    "The username is already being used" : "نام‌کاربری قبلا استفاده شده است",
    "Could not create user" : "نتواسنت کاربر را ایجاد کند",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"",
    "A valid username must be provided" : "نام کاربری صحیح باید وارد شود",
    "Username contains whitespace at the beginning or at the end" : "نام کاربری دارای فضای سفید در ابتدا یا انتهای آن است",
    "Username must not consist of dots only" : "نام کاربری نباید فقط از نقاط تشکیل شده باشد",
    "Username is invalid because files already exist for this user" : "Username is invalid because files already exist for this user",
    "User disabled" : "کاربر از کار افتاده",
    "File is currently busy, please try again later" : "فایل در حال حاضر مشغول است، لطفا مجددا تلاش کنید",
    "Cannot download file" : "نمی‌توان پرونده را بارگرفت",
    "Your data directory is readable by other users." : "Your data directory is readable by other users.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "لطفاً مجوزها را به 0770 تغییر دهید تا فهرست توسط سایر کاربران فهرست نشود.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "اطمینان حاصل کنید که فایلی به نام \".ocdata\" در ریشه دایرکتوری داده وجود دارد."
},
"nplurals=2; plural=(n > 1);");
